define(
//begin v1.x content
{
	"HKD_displayName": "dollar de Hong Kong",
	"CHF_displayName": "franc suisse",
	"JPY_symbol": "JPY",
	"CAD_displayName": "dollar canadien",
	"HKD_symbol": "HKD",
	"CNY_displayName": "yuan renminbi chinois",
	"USD_symbol": "$US",
	"AUD_displayName": "dollar australien",
	"JPY_displayName": "yen japonais",
	"CAD_symbol": "$CA",
	"USD_displayName": "dollar des États-Unis",
	"EUR_symbol": "€",
	"CNY_symbol": "CNY",
	"GBP_displayName": "livre sterling",
	"GBP_symbol": "£GB",
	"AUD_symbol": "$AU",
	"EUR_displayName": "euro"
}
//end v1.x content
);